# Leximetry: Qualitative Metrics for Prose

This is a new experimental approach to summarizing some qualitative metrics of writing.

See [leximetry.md](src/leximetry/docs/leximetry.md) for more on how it works.

## Usage

Install with `uv tool install --upgrade leximetry`. [Using uv](installation.md) is
highly recommended.

## Example

<div align="center">

<img width="713" alt="Example run of leximetry" src="https://github.com/user-attachments/assets/633d1c1b-4918-4f67-9f7a-472e08fb984a" />

</div>

* * *

## Project Docs

For how to install uv and Python, see [installation.md](installation.md).

For development workflows, see [development.md](development.md).

For instructions on publishing to PyPI, see [publishing.md](publishing.md).

* * *

*This project was built from
[simple-modern-uv](https://github.com/jlevy/simple-modern-uv).*
